@@ -1,6 +1,7 @@
 from cgitb import text
 import logging
-import re
+import schedule
+import datetime
 
 from pexpect import TIMEOUT
 from telegram import Update
@@ -50,7 +51,7 @@ def get_ruuvi_data():
         ruuvi_data[ruuvi_data_point]["name"] = ruuvi_tags[ruuvi_data_point]["name"]
         ruuvi_data[ruuvi_data_point]["temperature_calibrated"] = (
             ruuvi_data[ruuvi_data_point]["temperature"]
-            + ruuvi_tags[ruuvi_data_point["mac"]]["temperatureOffset"]
+            + ruuvi_tags[ruuvi_data_point]["temperatureOffset"]
         )
 
     logging.info("Writing data to database")
@@ -61,7 +62,7 @@ def get_ruuvi_data():
     c.execute(
         "CREATE TABLE IF NOT EXISTS ruuvi (datetime text, name text, temperature real, temperature_calibrated real, humidity real, pressure real)"
     )
-    for ruuvi_data_point in ruuvi_data:
+    for ruuvi_data_point in ruuvi_data.values():
         c.execute(
             "INSERT INTO ruuvi VALUES (datetime('now'), ?, ?, ?, ?, ?)",
             (
@@ -127,10 +128,19 @@ async def temperature(update: Update, context: ContextTypes.DEFAULT_TYPE):
     # Get the data from sqlite database for all sensors in settings
     conn = sqlite3.connect("dbdata/temperature.sqlite")
     c = conn.cursor()
-    c.execute("SELECT * FROM ruuvi ORDER BY datetime DESC LIMIT 1 where name in (?)", [r['name'] for r in SETTINGS['ruuvitags']])
-    data = c.fetchall()
-    text = json.dumps(data, indent=4, sort_keys=True)
 
+    text = ""
+
+    for ruuvi in SETTINGS["ruuvitags"]:
+        c.execute(
+            "SELECT * FROM ruuvi where name = ? ORDER BY datetime DESC LIMIT 1",
+            (ruuvi["name"],),
+        )
+        data = c.fetchone()
+        # Calculate the time since the last update
+        time_since_update = datetime.datetime.now() - datetime.datetime.strptime(data[0], '%Y-%m-%d %H:%M:%S')
+        text += f"{data[1]}: {data[3]} °C  ({ time_since_update.min } minuuttia sitten) \n" 
+    
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
 
 
@@ -263,6 +273,9 @@ def main():
     application.add_handler(CommandHandler("set", set_timer))
     application.add_handler(CommandHandler("unset", unset))
 
+    # Update ruuvi data every 5 minutes
+    schedule.every(5).minutes.do(get_ruuvi_data)
+
     application.run_polling()
 
 
